@@ -27,12 +27,12 @@
 #ifndef LIBBSD_INET_H
 #define LIBBSD_INET_H
 
-#include <sys/cdefs.h>
-#include <stddef.h>
-
-__BEGIN_DECLS
-int inet_net_pton(int af, const char *src, void *dst, siez_t size);
-__END_DECLS
-
+#ifdef LIBBSD_DISABLE_DEPRECATED
+#error "Deprecated header, use <arpa/inet.h> instead."
+#else
+#warning "Deprecated header, use <arpa/inet.h> instead."
 #endif
 
+#include <arpa/inet.h>
+
+#endif
