@@ -27,9 +27,16 @@
 #ifndef LIBBSD_BSD_QUEUE_H
 #define LIBBSD_BSD_QUEUE_H
 
-#warning "This header is deprecated, use the one in bsd/sys/queue.h instead."
-
-#include <bsd/sys/queue.h>
-
+#ifdef LIBBSD_DISABLE_DEPRECATED
+#error "Deprecated header, use <bsd/sys/queue.h> or libbsd-overlay.pc instead."
+#else
+#warning "Deprecated header, use <bsd/sys/queue.h> or libbsd-overlay.pc instead."
 #endif
 
+#ifdef LIBBSD_OVERLAY
+#include <sys/queue.h>
+#else
+#include <bsd/sys/queue.h>
+#endif
+
+#endif
